# Whatify_Toolkit
Welcome to Whatify Toolkit

## Installation:

`pip3 install toolkit_w pytest allure-pytest s3fs boto3`

## Usage:

```
import toolkit_w as my_tool

myWhatify = my_tool.MyWhatify()

myWhatify.login(USER, PASSWORD)

```

